window.Gleam.initSearch([{"doc":"gleamyshell","title":"gleamyshell","content":"# GleamyShell\n\nGleamyShell is a cross-platform Gleam library for executing shell commands that supports multiple targets (Erlang, Deno,\nand Node.js).\n\n## When to use GleamyShell?\n\nGleamyShell provides the ability to execute shell commands on multiple targets. While this might sound amazing,\nsupporting targets with fundamentally different concurrency models and APIs shrinks the common ground significantly.\n\nIn order to keep the public API homogenous across different targets, GleamyShell only provides synchronous bindings and\na minimal API with common functionalities supported by those targets.\n\nYou should use GleamyShell if\n\n-   you need or want to support multiple targets _and/or_\n-   synchronous shell command execution is not a concern _and most importantly_\n-   you don&#39;t have special use cases that GleamyShell&#39;s API cannot serve\\*.\n\n\\* Feel free to [open an issue](https://github.com/patrik-kuehl/gleamyshell/issues) on GitHub to discuss your feature\nrequest. GleamyShell only implements features that can provide the same behavior on all supported targets. Yours might\nbe one of them.\n\n## Usage\n\n### Getting the current username\n\n```gleam\nlet result = gleamyshell.execute(&quot;whoami&quot;, [])\n\ncase result {\n  Ok(username) -&gt;\n    io.println(&quot;Hello there, &quot; &lt;&gt; string.trim(username) &lt;&gt; &quot;!&quot;)\n  Error(Failure(output, exit_code)) -&gt;\n    io.println(\n      &quot;Whoops!\\nError (&quot;\n      &lt;&gt; int.to_string(exit_code)\n      &lt;&gt; &quot;): &quot;\n      &lt;&gt; string.trim(output),\n    )\n  Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n}\n```\n\n### Getting the current working directory\n\n```gleam\ncase gleamyshell.cwd() {\n  Some(working_directory) -&gt;\n    io.println(&quot;Current working directory: &quot; &lt;&gt; working_directory)\n  None -&gt;\n    io.println(&quot;Couldn&#39;t detect the current working directory.&quot;)\n}\n```\n\n### Choosing what to do depending on the operating system\n\n```gleam\ncase gleamyshell.os() {\n  Windows -&gt; io.println(&quot;Doing stuff on Windows.&quot;)\n  Unix(Darwin) -&gt; io.println(&quot;Doing stuff on macOS.&quot;)\n  Unix(_) -&gt; io.println(&quot;Doing stuff on a Unix(-like) system.&quot;)\n}\n```\n\n## Changelog\n\nTake a look at the [changelog](https://github.com/patrik-kuehl/gleamyshell/blob/main/CHANGELOG.md) to get an overview of\neach release and its changes.\n\n## Contribution Guidelines\n\nMore information can be found [here](https://github.com/patrik-kuehl/gleamyshell/blob/main/CONTRIBUTING.md).\n\n## License\n\nGleamyShell is licensed under the [MIT license](https://github.com/patrik-kuehl/gleamyshell/blob/main/LICENSE.md).\n","url":"index.html"},{"doc":"gleamyshell","title":"gleamyshell","content":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThis project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## 0.4.0 - 2024-05-31\n\n### Features\n\n-   Implemented the `env` function.\n-   Implemented the `which` function.\n\n## 0.3.1 - 2024-05-29\n\n### Bug Fixes\n\n-   Made the internal `cwd_ffi` function private again.\n\n## 0.3.0 - 2024-05-29\n\n### Features\n\n-   Implemented the `home_directory` function.\n\n### Bug Fixes\n\n-   [**breaking**] The `cwd` function now provides a consistent output across all supported targets.\n-   Removed the freezing of the standard library version for consumers of the library. Discovered and fixed thanks to\n    [@darky](https://github.com/darky).\n\n## 0.2.0 - 2024-05-28\n\n### Features\n\n-   Implemented the `os` function.\n-   [**breaking**] Defined the `OsFamily` and `Os` types, and renamed a constructor of the `AbortReason` type.\n\n## 0.1.0 - 2024-05-26\n\n### Features\n\n-   Implemented the `execute_in` function.\n-   Implemented the `cwd` function.\n-   Implemented the `execute` function.\n-   Defined the `CommandError` and `AbortReason` types.\n\n&lt;!-- scaffolded by git-cliff --&gt;\n","url":"changelog.html"},{"doc":"gleamyshell","title":"gleamyshell","content":"# MIT License\n\nCopyright (c) 2024 Patrik Kühl\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated\ndocumentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the\nrights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit\npersons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the\nSoftware.\n\nTHE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE\nWARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR\nOTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n","url":"license.html"},{"doc":"gleamyshell","title":"AbortReason","content":"pub type AbortReason {\n  Enomem\n  Eagain\n  Enametoolong\n  Emfile\n  Enfile\n  Eacces\n  Enoent\n  OtherAbortReason(String)\n}\n Represents the reason why the execution of a command was aborted.\n\n Most of these reasons are common POSIX errors.\nEnomem\n Not enough memory.\n\nEagain\n Resource temporarily unavailable.\n\nEnametoolong\n Too long file name.\n\nEmfile\n Too many open files.\n\nEnfile\n File table overflow.\n\nEacces\n Insufficient permissions.\n\nEnoent\n No such file or directory.\n\nOtherAbortReason(String)\n An error not represented by the other options.\n\nSynonyms:\ngleamyshell.AbortReason\ngleamyshell AbortReason","url":"gleamyshell.html#AbortReason"},{"doc":"gleamyshell","title":"CommandError","content":"pub type CommandError {\n  Failure(output: String, exit_code: Int)\n  Abort(reason: AbortReason)\n}\n Represents information about why a command execution failed.\nFailure(output: String, exit_code: Int)\n The command could be executed but returned a non-zero exit code.\n\nAbort(reason: AbortReason)\n The command did not execute and instead was aborted.\n\nSynonyms:\ngleamyshell.CommandError\ngleamyshell CommandError","url":"gleamyshell.html#CommandError"},{"doc":"gleamyshell","title":"Os","content":"pub type Os {\n  Darwin\n  FreeBsd\n  OpenBsd\n  Linux\n  SunOs\n  OtherOs(String)\n}\n Represents names of operating systems.\nDarwin\n The Unix operating system used by Apple as a core for its operating systems (e.g., macOS).\n\nFreeBsd\n A free Unix-like operating system descended from AT&amp;T&#39;s UNIX.\n\nOpenBsd\n A free Unix-like operating system forked from NetBSD.\n\nLinux\n The Linux kernel is the base for many Unix-like operating systems like Debian.\n\nSunOs\n The Unix-like operating system SunOS is used as a core for other distributions like Solaris.\n\nOtherOs(String)\n An operating system not represented by the other options.\n\nSynonyms:\ngleamyshell.Os\ngleamyshell Os","url":"gleamyshell.html#Os"},{"doc":"gleamyshell","title":"OsFamily","content":"pub type OsFamily {\n  Unix(Os)\n  Windows\n}\n Represents families of operating systems.\nUnix(Os)\n The operating system is part of the Unix family.\n\nWindows\n The operating system is part of the Windows family.\n\nSynonyms:\ngleamyshell.OsFamily\ngleamyshell OsFamily","url":"gleamyshell.html#OsFamily"},{"doc":"gleamyshell","title":"cwd","content":"pub fn cwd() -&gt; Option(String)\n Returns the current working directory.\n \n This function returns an `Option` because it can fail on Unix-like systems in rare circumstances.\n \n ## Example\n \n \n case gleamyshell.cwd() {\n   Some(working_directory) -&gt;\n     io.println(&quot;Current working directory: &quot; &lt;&gt; working_directory)\n   None -&gt; io.println(&quot;Couldn&#39;t detect the current working directory.&quot;)\n }\n \nSynonyms:\ngleamyshell.cwd\ngleamyshell cwd","url":"gleamyshell.html#cwd"},{"doc":"gleamyshell","title":"env","content":"pub fn env(identifier: String) -&gt; Option(String)\n Returns the value of the given environment variable when it is set.\n \n ## Example\n \n \n case gleamyshell.env(&quot;JAVA_HOME&quot;) {\n   Some(dir) -&gt; io.println(&quot;Java runtime location: &quot; &lt;&gt; dir)\n   None -&gt; \n     io.println(&quot;The location of the Java runtime could not be found.&quot;)\n }\n \nSynonyms:\ngleamyshell.env\ngleamyshell env","url":"gleamyshell.html#env"},{"doc":"gleamyshell","title":"execute","content":"pub fn execute(\n  command command: String,\n  args args: List(String),\n) -&gt; Result(String, CommandError)\n Executes the given command with arguments.\n\n ## Example\n \n \n let result = gleamyshell.execute(&quot;whoami&quot;, [])\n \n case result {\n   Ok(username) -&gt;\n     io.println(&quot;Hello there, &quot; &lt;&gt; string.trim(username) &lt;&gt; &quot;!&quot;)\n   Error(Failure(output, exit_code)) -&gt;\n     io.println(\n       &quot;Whoops!\\nError (&quot;\n       &lt;&gt; int.to_string(exit_code)\n       &lt;&gt; &quot;): &quot;\n       &lt;&gt; string.trim(output),\n     )\n   Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n }\n \n \n This function can also be invoked by using labelled arguments.\n \n \n let result = gleamyshell.execute(&quot;ls&quot;, args: [&quot;-la&quot;])\n let another_result = gleamyshell.execute(command: &quot;ls&quot;, args: [&quot;-la&quot;])\n \nSynonyms:\ngleamyshell.execute\ngleamyshell execute","url":"gleamyshell.html#execute"},{"doc":"gleamyshell","title":"execute_in","content":"pub fn execute_in(\n  command command: String,\n  args args: List(String),\n  working_directory working_directory: String,\n) -&gt; Result(String, CommandError)\n Executes the given command with arguments in a specified working directory.\n\n ## Example\n \n \n let result =\n   gleamyshell.execute_in(&quot;cat&quot;, [&quot;.bashrc&quot;], &quot;/home/username&quot;)\n \n case result {\n   Ok(file_content) -&gt; io.println(file_content)\n   Error(Failure(output, exit_code)) -&gt;\n     io.println(\n       &quot;Whoops!\\nError (&quot;\n       &lt;&gt; int.to_string(exit_code)\n       &lt;&gt; &quot;): &quot;\n       &lt;&gt; string.trim(output),\n     )\n   Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n }\n \n \n This function can also be invoked by using labelled arguments.\n \n \n let result =\n   gleamyshell.execute_in(\n     &quot;ls&quot;,\n     args: [&quot;-la&quot;],\n     working_directory: &quot;/usr/bin&quot;,\n   )\n \n let another_result =\n   gleamyshell.execute_in(\n     command: &quot;ls&quot;,\n     args: [&quot;-la&quot;],\n     working_directory: &quot;/usr/bin&quot;,\n   )\n \nSynonyms:\ngleamyshell.execute_in\ngleamyshell execute_in","url":"gleamyshell.html#execute_in"},{"doc":"gleamyshell","title":"home_directory","content":"pub fn home_directory() -&gt; Option(String)\n Returns the home directory of the current user.\n \n This function returns an `Option` because it can fail in rare circumstances.\n \n ## Example\n \n \n case gleamyshell.home_directory() {\n   Some(home_directory) -&gt; io.println(&quot;Home directory: &quot; &lt;&gt; home_directory)\n   None -&gt;\n     io.println(&quot;Couldn&#39;t detect the home directory of the current user.&quot;)\n }\n \nSynonyms:\ngleamyshell.home_directory\ngleamyshell home_directory","url":"gleamyshell.html#home_directory"},{"doc":"gleamyshell","title":"os","content":"pub fn os() -&gt; OsFamily\n Returns information about the host&#39;s operating system.\n \n This function is meant to be a quality-of-life feature where someone needs to execute different\n shell commands that differ depending on the operating system.\n \n ## Example\n \n \n case gleamyshell.os() {\n   Windows -&gt; io.println(&quot;Doing stuff on Windows.&quot;)\n   Unix(_) -&gt; io.println(&quot;Doing stuff on a Unix(-like) system.&quot;)\n }\n \nSynonyms:\ngleamyshell.os\ngleamyshell os","url":"gleamyshell.html#os"},{"doc":"gleamyshell","title":"which","content":"pub fn which(executable: String) -&gt; Option(String)\n Returns the location of the given executable when it could be found.\n \n ## Example\n \n \n case gleamyshell.which(&quot;git&quot;) {\n   Some(_) -&gt; io.println(&quot;Doing something with Git.&quot;)\n   None -&gt; io.println(&quot;Git could not be found.&quot;)\n }\n \nSynonyms:\ngleamyshell.which\ngleamyshell which","url":"gleamyshell.html#which"},{"doc":"gleamyshell","title":"gleamyshell","content":"","url":"gleamyshell.html"}]);